@@ -26,7 +26,7 @@ def format(args):
     path_to_data = validate_path(args.path)
     doc = Document(path_to_data)
 
-    format_table(doc, cols_to_format)
+    format_table(doc, cols_to_format, force_capitalize=args.capitalize)
     doc.save(path_to_data)
 
 
@@ -54,6 +54,11 @@ def main():
     format_parser = subparsers.add_parser(
         "format", parents=[path_parser], help="format a Science Bowl file"
     )
+    format_parser.add_argument(
+        "--capitalize",
+        action="store_true",
+        help="force all answer lines to be capitalized",
+    )
     format_parser.set_defaults(func=format)
 
     make_parser = subparsers.add_parser(
