@@ -22,6 +22,7 @@ from .docx_utils import (
     preprocess_cell,
     shade_columns,
     split_run_at,
+    move_runs_to_end_of_para,
 )
 
 COL_WIDTHS = (
@@ -180,9 +181,16 @@ class QuestionCellFormatter(CellFormatter):
 
     _choices = ("W)", "X)", "Y)", "Z)")
 
-    def __init__(self, cell: _Cell, error_logger: Optional[ErrorLogger] = None):
+    def __init__(
+        self,
+        cell: _Cell,
+        force_capitalize: bool = False,
+        error_logger: Optional[ErrorLogger] = None,
+    ):
         self.error_logger = error_logger
         self.cell = cell
+        self.force_capitalize = force_capitalize
+
         self.state = QuestionFormatterState.Q_START
         self.q_type = None
         self.q_type_run = None
@@ -219,10 +227,23 @@ class QuestionCellFormatter(CellFormatter):
                     self.error_logger.log_error("Couldn't parse question.")
                 return None
 
-            # now, the first part of the stem is the second run
-            # if it's not left-padded with 4 spaces, make sure it is
-            # doing it this way ensures that any other formatting in
-            # the stem is preserved (superscripts, subscripts, etc.)
+            # if this para only has 1 run, the stem should be in the next paragraph.
+            if len(para.runs) == 1:
+                next_para = para._p.getnext()
+                next_para_text = "".join(_r.text for _r in next_para if _r.text)
+                # need to check if there even IS a stem - next paragraph shouldn't start
+                # with W) or ANSWER:
+                if self._choices_re.match(next_para_text) or self._answer_re.match(
+                    next_para_text
+                ):
+                    highlight_cell_text(self.cell, WD_COLOR_INDEX.RED)
+                    if self.error_logger is not None:
+                        self.error_logger.log_error("Couldn't parse question.")
+
+                else:
+                    move_runs_to_end_of_para(next_para, para)
+
+            # left pad the first run of the stem
             stem_run = para.runs[1]
             stem_run.text = f"    {stem_run.text.lstrip()}"
 
@@ -263,14 +284,16 @@ class QuestionCellFormatter(CellFormatter):
                 self.state = QuestionFormatterState.ANSWER
 
     def _answer_handler(self, para: Paragraph):
-        # if we find a choice line while looking for an answer,
-        # the question is probably not Short Answer. highlight
-        # the question type to indicate this
 
         answer_match = self._answer_re.match(para.text)
         if answer_match:
             para.insert_paragraph_before("")
 
+            # if we're forcing capitalization, apply it now
+            if self.force_capitalize:
+                for run in para.runs:
+                    run.text = run.text.upper()
+
             # for MC questions, additional checks to make sure
             # answer line matches choice
             if self.q_type is QuestionType.MULTIPLE_CHOICE:
@@ -476,13 +499,16 @@ def format_column(
         if error_logger is not None:
             error_logger.set_row(idx + 1)
         if cell.text.strip() != "" and formatter:
-            formatter(cell, error_logger).format()
+            formatter(cell, error_logger=error_logger).format()
     return nsb_table_column
 
 
 def format_table(
-    table_doc: docx.document.Document, cols_to_format: Tuple[str], verbosity=True
-):
+    table_doc: docx.document.Document,
+    cols_to_format: Tuple[str],
+    force_capitalize: bool = False,
+    verbosity: bool = True,
+) -> None:
     """Formats a Word document containing a Science Bowl question table.
 
     Specifically, this function makes sure the columns fit the following
@@ -504,7 +530,7 @@ def format_table(
     FORMATTERS = {
         "TUB": TuBCellFormatter,
         "Subj": SubjectCellFormatter,
-        "Ques": QuestionCellFormatter,
+        "Ques": partial(QuestionCellFormatter, force_capitalize=force_capitalize),
         "LOD": DifficultyFormatter,
     }
     error_logger = ErrorLogger(verbosity)
